@@ -4,6 +4,7 @@ from fief_client.client import (
     FiefAccessTokenExpired,
     FiefAccessTokenInfo,
     FiefAccessTokenInvalid,
+    FiefAccessTokenMissingPermission,
     FiefAccessTokenMissingScope,
     FiefAsync,
     FiefError,
@@ -12,7 +13,7 @@ from fief_client.client import (
     FiefUserInfo,
 )
 
-__version__ = "0.11.0"
+__version__ = "0.13.0"
 
 __all__ = [
     "Fief",
@@ -22,6 +23,7 @@ __all__ = [
     "FiefUserInfo",
     "FiefError",
     "FiefAccessTokenExpired",
+    "FiefAccessTokenMissingPermission",
     "FiefAccessTokenMissingScope",
     "FiefAccessTokenInvalid",
     "FiefIdTokenInvalid",
